( cd usr/share/applications ; rm -rf gimp-2.2.desktop )
( cd usr/share/applications ; ln -sf /usr/share/gimp/2.0/misc/gimp.desktop gimp-2.2.desktop )
( cd usr/share/application-registry ; rm -rf gimp-2.2.applications )
( cd usr/share/application-registry ; ln -sf /usr/share/gimp/2.0/misc/gimp.applications gimp-2.2.applications )
( cd usr/share/man/man1 ; rm -rf gimp.1 )
( cd usr/share/man/man1 ; ln -sf gimp-2.2.1 gimp.1 )
( cd usr/share/man/man1 ; rm -rf gimp-remote.1 )
( cd usr/share/man/man1 ; ln -sf gimp-remote-2.2.1 gimp-remote.1 )
( cd usr/share/man/man5 ; rm -rf gimprc.5 )
( cd usr/share/man/man5 ; ln -sf gimprc-2.2.5 gimprc.5 )
( cd usr/share/mime-info ; rm -rf gimp.keys )
( cd usr/share/mime-info ; ln -sf ../gimp/2.0/misc/gimp.keys gimp.keys )
( cd usr/share/pixmaps ; rm -rf gimp.png )
( cd usr/share/pixmaps ; ln -sf ../icons/hicolor/48x48/apps/gimp.png gimp.png )
( cd usr/bin ; rm -rf gimp-remote )
( cd usr/bin ; ln -sf gimp-remote-2.2 gimp-remote )
( cd usr/bin ; rm -rf gimp )
( cd usr/bin ; ln -sf gimp-2.2 gimp )
( cd usr/lib ; rm -rf libgimpbase-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpbase-2.0.so.0.200.12 libgimpbase-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpbase-2.0.so )
( cd usr/lib ; ln -sf libgimpbase-2.0.so.0.200.12 libgimpbase-2.0.so )
( cd usr/lib ; rm -rf libgimpcolor-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpcolor-2.0.so.0.200.12 libgimpcolor-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpcolor-2.0.so )
( cd usr/lib ; ln -sf libgimpcolor-2.0.so.0.200.12 libgimpcolor-2.0.so )
( cd usr/lib ; rm -rf libgimpmath-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpmath-2.0.so.0.200.12 libgimpmath-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpmath-2.0.so )
( cd usr/lib ; ln -sf libgimpmath-2.0.so.0.200.12 libgimpmath-2.0.so )
( cd usr/lib ; rm -rf libgimpmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpmodule-2.0.so.0.200.12 libgimpmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpmodule-2.0.so )
( cd usr/lib ; ln -sf libgimpmodule-2.0.so.0.200.12 libgimpmodule-2.0.so )
( cd usr/lib ; rm -rf libgimpthumb-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpthumb-2.0.so.0.200.12 libgimpthumb-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpthumb-2.0.so )
( cd usr/lib ; ln -sf libgimpthumb-2.0.so.0.200.12 libgimpthumb-2.0.so )
( cd usr/lib ; rm -rf libgimpwidgets-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpwidgets-2.0.so.0.200.12 libgimpwidgets-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpwidgets-2.0.so )
( cd usr/lib ; ln -sf libgimpwidgets-2.0.so.0.200.12 libgimpwidgets-2.0.so )
( cd usr/lib ; rm -rf libgimp-2.0.so.0 )
( cd usr/lib ; ln -sf libgimp-2.0.so.0.200.12 libgimp-2.0.so.0 )
( cd usr/lib ; rm -rf libgimp-2.0.so )
( cd usr/lib ; ln -sf libgimp-2.0.so.0.200.12 libgimp-2.0.so )
( cd usr/lib ; rm -rf libgimpui-2.0.so.0 )
( cd usr/lib ; ln -sf libgimpui-2.0.so.0.200.12 libgimpui-2.0.so.0 )
( cd usr/lib ; rm -rf libgimpui-2.0.so )
( cd usr/lib ; ln -sf libgimpui-2.0.so.0.200.12 libgimpui-2.0.so )

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi
